==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/E_GENSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.event.E_GEN;
import io.ciera.tool.sql.ooaofooa.event.E_GENSet;
import io.ciera.tool.sql.ooaofooa.event.GenerateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.impl.GenerateSMEventStatementSetImpl;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;

import java.util.Arrays;
import java.util.List;


public class E_GENSetImpl extends InstanceSet<E_GENSet,E_GEN> implements E_GENSet {

    // attributes
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( E_GEN e_gen : this ) e_gen.setVar_ID( ref_Var_ID );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( E_GEN e_gen : this ) e_gen.setStatement_ID( ref_Statement_ID );
    }


    // selections
    @Override
    public GenerateSMEventStatementSet R705_is_a_GenerateSMEventStatement() throws XtumlException {
        GenerateSMEventStatementSet generatesmeventstatementset = new GenerateSMEventStatementSetImpl();
        for ( E_GEN e_gen : this ) generatesmeventstatementset.add( e_gen.R705_is_a_GenerateSMEventStatement() );
        return generatesmeventstatementset;
    }
    @Override
    public V_VARSet R712_has_recipient_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( E_GEN e_gen : this ) v_varset.add( e_gen.R712_has_recipient_V_VAR() );
        return v_varset;
    }


    @Override
    public E_GEN nullElement() {
        return E_GENImpl.EMPTY_E_GEN;
    }

    @Override
    public E_GENSet emptySet() {
      return new E_GENSetImpl();
    }

    @Override
    public E_GENSet value() {
        return this;
    }

    @Override
    public List<E_GEN> elements() {
        return Arrays.asList(toArray(new E_GEN[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/E_GENSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.event.E_GEN;
import io.ciera.tool.sql.ooaofooa.event.E_GENSet;
import io.ciera.tool.sql.ooaofooa.event.GenerateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.impl.GenerateSMEventStatementSetImpl;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class E_GENSetImpl extends InstanceSet<E_GENSet,E_GEN> implements E_GENSet {

    public E_GENSetImpl() {
    }

    public E_GENSetImpl(Comparator<? super E_GEN> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( E_GEN e_gen : this ) e_gen.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( E_GEN e_gen : this ) e_gen.setVar_ID( ref_Var_ID );
    }


    // selections
    @Override
    public GenerateSMEventStatementSet R705_is_a_GenerateSMEventStatement() throws XtumlException {
        GenerateSMEventStatementSet generatesmeventstatementset = new GenerateSMEventStatementSetImpl();
        for ( E_GEN e_gen : this ) generatesmeventstatementset.add( e_gen.R705_is_a_GenerateSMEventStatement() );
        return generatesmeventstatementset;
    }
    @Override
    public V_VARSet R712_has_recipient_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( E_GEN e_gen : this ) v_varset.add( e_gen.R712_has_recipient_V_VAR() );
        return v_varset;
    }


    @Override
    public E_GEN nullElement() {
        return E_GENImpl.EMPTY_E_GEN;
    }

    @Override
    public E_GENSet emptySet() {
      return new E_GENSetImpl();
    }

    @Override
    public E_GENSet emptySet(Comparator<? super E_GEN> comp) {
      return new E_GENSetImpl(comp);
    }

    @Override
    public E_GENSet value() {
        return this;
    }

    @Override
    public List<E_GEN> elements() {
        return Arrays.asList(toArray(new E_GEN[0]));
    }

}
